package Catalyst::Model::state51::Tangram;
use base qw/Catalyst::Model/;
use strict;
use warnings;
use state51::Base;
use MRO::Compat;

our $VERSION = '2012121200';

BEGIN {
    __PACKAGE__->mk_accessors(qw/
        storage
        schema
        dbname
        dbhost
        dbhost_readonly
        dbusername
        dbpassword
        execute_on_connect
    /);
}

sub _set_db_env_vars_from_config {
    my ($self) = @_;
    my $class = ref($self);
    $ENV{DBHOST}          = $self->dbhost          || $ENV{DBHOST}          || die("No dbhost setup for $class");
    $ENV{DBHOST_READONLY} = $self->dbhost_readonly || $ENV{DBHOST_READONLY} || $ENV{DBHOST};
    $ENV{DATABASE}        = $self->dbname          || $ENV{DATABASE}        || die("No dbname setup for $class");
    $ENV{DBUSER}          = $self->dbusername      || $ENV{DBUSER}          || die("No dbusername setup for $class");
    $ENV{DBPASS}          = $self->dbpassword      || $ENV{DBPASS}          || die("No dbpassword setup for $class");
}

sub COMPONENT {
    my ($class, $app, @rest) = @_;
    my $self = $class->next::method($app, @rest);
    $self->_set_db_env_vars_from_config; # FIXME, this should be able to be unfucked now.
    state51::Base->tangram_storage->execute_on_connect(
        @{$self->execute_on_connect}
    ) if $self->execute_on_connect;

    state51::Base->connect;
    $self->{storage} = state51::Base->storage;
    $self->{schema} = $self->storage->schema;
    die("No self") unless $self;
    return $self;
}

sub connect {
    state51::Base->reconnect_if_dead;
}

1;

__END__

=head1 NAME

Catalyst::Model::state51::Tangram - Generic model for glueing the state51 Tangram objects into a Catalyst application.

=cut

